@@ -10,10 +10,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 r"""
-Finetuning Scheduler
-^^^^^^^^^^^^^^^^^^^^
+Fine-Tuning Scheduler
+^^^^^^^^^^^^^^^^^^^^^
 
-Used to implement flexible finetuning training schedules
+Used to implement flexible fine-tuning training schedules
 
 """
 import logging
@@ -41,14 +41,14 @@ log = logging.getLogger(__name__)
 
 class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMixin):
     r"""
-    This callback enables flexible, multi-phase, scheduled finetuning of foundational models. Gradual unfreezing/thawing
-    can help maximize foundational model knowledge retention while allowing (typically upper layers of) the model to
-    optimally adapt to new tasks during transfer learning.
-    :class:`~finetuning_scheduler.fts.FinetuningScheduler` orchestrates the gradual
-    unfreezing of models via a finetuning schedule that is either implicitly generated (the default) or explicitly
-    provided by the user (more computationally efficient).
+    This callback enables flexible, multi-phase, scheduled fine-tuning of foundational models. Gradual
+    unfreezing/thawing can help maximize foundational model knowledge retention while allowing (typically upper layers
+    of) the model to optimally adapt to new tasks during transfer learning.
+    :class:`~finetuning_scheduler.fts.FinetuningScheduler` orchestrates the gradual unfreezing of models via a
+    fine-tuning schedule that is either implicitly generated (the default) or explicitly provided by the user (more
+    computationally efficient).
 
-    Finetuning phase transitions are driven by
+    Fine-tuning phase transitions are driven by
     :class:`~finetuning_scheduler.fts_supporters.FTSEarlyStopping` criteria (a multi-phase
     extension of :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping`), user-specified epoch
     transitions or a composition of the two (the default mode). A
@@ -58,11 +58,11 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
 
     Schedule definition is facilitated via
     :meth:`~finetuning_scheduler.fts_supporters.ScheduleImplMixin.gen_ft_schedule` which dumps
-    a default finetuning schedule (by default using a naive, 2-parameters per level heuristic) which can be adjusted as
-    desired by the user and subsuquently passed to the callback. Implicit finetuning mode generates the default schedule
-    and proceeds to finetune according to the generated schedule. Implicit finetuning will often be less computationally
-    efficient than explicit finetuning but can often serve as a good baseline for subsquent explicit schedule refinement
-    and can marginally outperform many explicit schedules.
+    a default fine-tuning schedule (by default using a naive, 2-parameters per level heuristic) which can be adjusted as
+    desired by the user and subsuquently passed to the callback. Implicit fine-tuning mode generates the default
+    schedule and proceeds to fine-tune according to the generated schedule. Implicit fine-tuning will often be less
+    computationally efficient than explicit fine-tuning but can often serve as a good baseline for subsquent explicit
+    schedule refinement and can marginally outperform many explicit schedules.
 
     Example::
 
@@ -81,31 +81,32 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
         epoch_transitions_only: bool = False,
         reinit_lr_cfg: Optional[Dict] = None,
         allow_untested: bool = False,
+        apply_lambdas_new_pgs: bool = False,
     ):
         r"""
-        Define and configure a scheduled finetuning training session.
+        Define and configure a scheduled fine-tuning training session.
 
         Args:
-            ft_schedule: The finetuning schedule to be executed. Usually will be a .yaml file path but can also be a
+            ft_schedule: The fine-tuning schedule to be executed. Usually will be a .yaml file path but can also be a
                 properly structured Dict. See
-                :ref:`Specifying a Finetuning Schedule<index:Specifying a Finetuning Schedule>`
+                :ref:`Specifying a Fine-Tuning Schedule<index:Specifying a fine-tuning schedule>`
                 for the basic schedule format. See
                 :ref:`LR Scheduler Reinitialization<explicit-lr-reinitialization-schedule>` for more complex
                 schedule configurations (including per-phase LR scheduler reinitialization). If a schedule is not
-                provided, will generate and execute a default finetuning schedule using the provided
+                provided, will generate and execute a default fine-tuning schedule using the provided
                 :external+pl:class:`~pytorch_lightning.core.lightning.LightningModule`. See
-                :ref:`the default schedule<index:The Default Finetuning Schedule>`. Defaults to ``None``.
-            max_depth: Maximum schedule depth to which the defined finetuning schedule should be executed. Specifying -1
-                or an integer > (number of defined schedule layers) will result in the entire finetuning schedule being
-                executed. Defaults to -1.
+                :ref:`the default schedule<index:The Default Fine-Tuning Schedule>`. Defaults to ``None``.
+            max_depth: Maximum schedule depth to which the defined fine-tuning schedule should be executed. Specifying
+                -1 or an integer > (number of defined schedule layers) will result in the entire fine-tuning schedule
+                being executed. Defaults to -1.
             base_max_lr: The default maximum learning rate to use for the parameter groups associated with each
-                scheduled finetuning depth if not explicitly specified in the finetuning schedule. If overridden to
-                ``None``, will be set to the ``lr`` of the first scheduled finetuning depth scaled by 1e-1. Defaults to
+                scheduled fine-tuning depth if not explicitly specified in the fine-tuning schedule. If overridden to
+                ``None``, will be set to the ``lr`` of the first scheduled fine-tuning depth scaled by 1e-1. Defaults to
                 1e-5.
             restore_best: If ``True``, restore the best available (defined by the
                 :class:`~finetuning_scheduler.fts_supporters.FTSCheckpoint`) checkpoint
-                before finetuning depth transitions. Defaults to ``True``.
-            gen_ft_sched_only: If ``True``, generate the default finetuning schedule to ``Trainer.log_dir`` (it will be
+                before fine-tuning depth transitions. Defaults to ``True``.
+            gen_ft_sched_only: If ``True``, generate the default fine-tuning schedule to ``Trainer.log_dir`` (it will be
                 named after your :external+pl:class:`~pytorch_lightning.core.lightning.LightningModule` subclass with
                 the suffix ``_ft_schedule.yaml``) and exit without training. Typically used to generate a default
                 schedule that will be adjusted by the user before training. Defaults to ``False``.
@@ -145,16 +146,19 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
                     :paramref:`~finetuning_scheduler.fts.FinetuningScheduler.allow_untested` to ``True``.
 
                     Some officially unsupported strategies may work unaltered and are only unsupported due to
-                    the ``Finetuning Scheduler`` project's lack of CI/testing resources for that strategy (e.g.
+                    the ``Fine-Tuning Scheduler`` project's lack of CI/testing resources for that strategy (e.g.
                     ``single_tpu``).
 
                     Most unsupported strategies, however, are currently unsupported because they require varying degrees
                     of modification to be compatible (e.g. ``deepspeed`` requires an ``add_param_group`` method,
                     ``tpu_spawn`` an override of the current broadcast method to include python objects).
-
+            apply_lambdas_new_pgs: If ``True``, applies most recent lambda in ``lr_lambdas`` list to newly added
+                optimizer groups for lr schedulers that have a ``lr_lambdas`` attribute. Note this option only applies
+                to phases without reinitialized lr schedulers. Phases with defined lr scheduler reinitialization configs
+                will always apply the specified lambdas. Defaults to ``False``.
 
         Attributes:
-            _fts_state: The internal finetuning scheduler state.
+            _fts_state: The internal :class:`~finetuning_scheduler.fts.FinetuningScheduler` state.
         """
         super().__init__()
         self._fts_state = FTSState()
@@ -166,23 +170,24 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
         self.epoch_transitions_only = epoch_transitions_only
         self.reinit_lr_cfg = reinit_lr_cfg
         self.allow_untested = allow_untested
+        self.apply_lambdas_new_pgs = apply_lambdas_new_pgs
         self.pl_module: pl.LightningModule
 
     @property
     def curr_depth(self) -> int:
-        """Index of the finetuning schedule depth currently being trained.
+        """Index of the fine-tuning schedule depth currently being trained.
 
         Returns:
-            int: The index of the current finetuning training depth
+            int: The index of the current fine-tuning training depth
         """
         return self._fts_state._curr_depth
 
     @property
     def depth_remaining(self) -> int:
-        """Remaining number of finetuning training levels in the schedule.
+        """Remaining number of fine-tuning training levels in the schedule.
 
         Returns:
-            int: The number of remaining finetuning training levels
+            int: The number of remaining fine-tuning training levels
         """
         return max(self.max_depth - self._fts_state._curr_depth, 0)
 
@@ -199,8 +204,8 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
         )
 
     def freeze_before_training(self, pl_module: "pl.LightningModule") -> None:
-        """Freezes all model parameters so that parameter subsets can be subsequently thawed according to the
-        finetuning schedule.
+        """Freezes all model parameters so that parameter subsets can be subsequently thawed according to the fine-
+        tuning schedule.
 
         Args:
             pl_module (:external+pl:class:`~pytorch_lightning.core.lightning.LightningModule`): The target
@@ -209,7 +214,7 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
         self.freeze(modules=pl_module)
 
     def step(self) -> None:
-        """Prepare and execute the next scheduled finetuning level
+        """Prepare and execute the next scheduled fine-tuning level
         1. Restore the current best model checkpoint if appropriate
         2. Thaw model parameters according the the defined schedule
         3. Synchronize the states of :external+pl:class:`~pytorch_lightning.loops.FitLoop` and
@@ -218,7 +223,7 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
         .. note::
 
             The :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback initially
-            only supports single-schedule/optimizer finetuning configurations
+            only supports single-schedule/optimizer fine-tuning configurations
         """
         assert self.pl_module.trainer is not None
         if not self._fts_state._resume_fit_from_ckpt:
@@ -237,14 +242,14 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
         rank_zero_info(f"Multi-phase fine-tuned training continuing at level {self.curr_depth}.")
 
     def step_pg(self, optimizer: Optimizer, depth: int, depth_sync: bool = True) -> None:
-        """Configure optimizer parameter groups for the next scheduled finetuning level, adding parameter groups
+        """Configure optimizer parameter groups for the next scheduled fine-tuning level, adding parameter groups
         beyond the restored optimizer state up to
         :paramref:`~finetuning_scheduler.fts.FinetuningScheduler.current_depth`
 
         Args:
             optimizer (:class:`~torch.optim.Optimizer`): The :class:`~torch.optim.Optimizer` to which parameter groups
                 will be configured and added.
-            depth: The maximum index of the finetuning schedule for which to configure the optimizer parameter
+            depth: The maximum index of the fine-tuning schedule for which to configure the optimizer parameter
                 groups.
             depth_sync: If ``True``, configure optimizer parameter groups for all depth indices greater
                 than the restored checkpoint. If ``False``, configure groups only for the specified depth. Defaults to
@@ -263,18 +268,33 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
                 _, self._fts_state._curr_thawed_params = FinetuningScheduler.exec_ft_phase(
                     self.pl_module, thaw_pl=next_tl["params"]
                 )
-                new_scheduler_cfg = self.reinit_lr_cfg or next_tl.get("new_lr_scheduler", None)
-                if new_scheduler_cfg:
-                    self.reinit_lr_scheduler(
-                        new_lr_scheduler=new_scheduler_cfg, trainer=self.pl_module.trainer, optimizer=optimizer
-                    )
                 FinetuningScheduler.add_optimizer_groups(
                     module=self.pl_module,
                     optimizer=optimizer,
                     thawed_pl=next_tl["params"],
                     lr=next_tl["lr"],
                     no_decay=getattr(self.pl_module, "no_decay", None),
+                    apply_lambdas=self.apply_lambdas_new_pgs,
                 )
+                new_scheduler_cfg = self.reinit_lr_cfg or next_tl.get("new_lr_scheduler", None)
+                if new_scheduler_cfg:
+                    self.reinit_lr_scheduler(
+                        new_lr_scheduler=new_scheduler_cfg, trainer=self.pl_module.trainer, optimizer=optimizer
+                    )
+                else:
+                    for config in self.pl_module.trainer.lr_scheduler_configs:
+                        show_warn_lambdas = (
+                            hasattr(config.scheduler, "lr_lambdas")
+                            and config.scheduler.lr_lambdas[-1] is not None  # type: ignore[union-attr]
+                            and not self.apply_lambdas_new_pgs
+                        )
+                        if show_warn_lambdas:
+                            rank_zero_warn(
+                                "The lr scheduler used in this phase has lr_lambdas but will use a "
+                                "configured lr for new parameter groups because `apply_lambdas_new_pgs` is "
+                                "set to the default of `False`. If you would like new groups to have lr "
+                                "lambdas applied, set `apply_lambdas_new_pgs` to `True`."
+                            )
 
     def restore_best_ckpt(self) -> None:
         """Restore the current best model checkpoint, according to
@@ -315,13 +335,21 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
 
         assert self.pl_module.trainer.state.fn is not None
         if self.pl_module.trainer.state.fn == TrainerFn.FITTING:
-            # restore optimizers and schedulers state
-            checkpoint_connector.restore_optimizers_and_schedulers()
+            try:
+                # restore optimizers and schedulers state
+                checkpoint_connector.restore_optimizers_and_schedulers()
+            except KeyError:
+                assert isinstance(self.ft_schedule, dict)
+                if self.ft_schedule[self.curr_depth].get("new_lr_scheduler", None):
+                    rank_zero_warn(
+                        "incompatible checkpoint detected but attempting to proceed with next phase of training since "
+                        "we're reinitializing the lr scheduler."
+                    )
 
     def setup(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", stage: Optional[str] = None) -> None:
         """Validate a compatible :external+pl:class:`~pytorch_lightning.strategies.Strategy` strategy is being used and
         ensure all :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback dependencies are met. If a valid
-        configuration is present, then either dump the default finetuning schedule OR
+        configuration is present, then either dump the default fine-tuning schedule OR
         1. configure the :class:`~finetuning_scheduler.fts_supporters.FTSEarlyStopping`
         callback (if relevant)
         2. initialize the :attr:`~finetuning_scheduler.fts.FinetuningScheduler._fts_state`
@@ -337,7 +365,7 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
             stage: The ``RunningStage.{SANITY_CHECKING,TRAINING,VALIDATING}``. Defaults to None.
 
         Raises:
-            SystemExit: Gracefully exit before training if only generating and not executing a finetuning schedule.
+            SystemExit: Gracefully exit before training if only generating and not executing a fine-tuning schedule.
             MisconfigurationException: If the
                 :external+pl:class:`~pytorch_lightning.strategies.Strategy` strategy being used is not currently
                 compatible with the :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback.
@@ -369,7 +397,7 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
             if trainer.is_global_zero:
                 assert trainer.log_dir is not None
                 _ = self.gen_ft_schedule(pl_module, trainer.log_dir)
-                log.info("Bypassing training, generating finetuning schedule for review and subsequent finetuning")
+                log.info("Bypassing training, generating fine-tuning schedule for review and subsequent fine-tuning")
             raise SystemExit()
         else:
             if not self.epoch_transitions_only:
@@ -468,11 +496,10 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
                 and (0 <= curr_max_epoch <= trainer.current_epoch)
                 else False
             )
-            phase_transition = (
-                True
-                if early_stopping_callback.es_phase_complete or epoch_driven_transition  # type: ignore[union-attr]
-                else False
-            )
+            if early_stopping_callback.es_phase_complete or epoch_driven_transition:  # type: ignore[union-attr]
+                phase_transition = True
+            else:
+                phase_transition = False
         else:  # we're only considering epoch-driven transition constraints
             phase_transition = True if 0 <= curr_max_epoch <= trainer.current_epoch else False
         return phase_transition
@@ -480,7 +507,7 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
     def on_train_epoch_start(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule") -> None:
         """Before beginning a training epoch, configure the internal
         :attr:`~finetuning_scheduler.fts.FinetuningScheduler._fts_state`, prepare the next
-        scheduled finetuning level and store the updated optimizer configuration before continuing training
+        scheduled fine-tuning level and store the updated optimizer configuration before continuing training
 
         Args:
             trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
@@ -500,7 +527,7 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
             self._fts_state._curr_depth += 1  # increment depth
             self.step()
             rank_zero_debug(
-                f"Current parameters thawed by the finetuning scheduler: {self._fts_state._curr_thawed_params}. "
+                f"Current parameters thawed by the Fine-Tuning Scheduler: {self._fts_state._curr_thawed_params}. "
                 f"Current depth is {self.curr_depth}."
             )
             if not self.epoch_transitions_only:
@@ -522,7 +549,7 @@ class FinetuningScheduler(BaseFinetuning, ScheduleImplMixin, ScheduleParsingMixi
     def on_before_zero_grad(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", optimizer: Optimizer) -> None:
         """Afer the latest optimizer step, update the
         :attr:`~finetuning_scheduler.fts.FinetuningScheduler._fts_state`, incrementing the
-        global finetuning steps taken
+        global fine-tuning steps taken
 
         Args:
             trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
