@@ -11,6 +11,7 @@
 # limitations under the License.
 import os.path
 import re
+import subprocess
 
 import pytest
 from packaging.version import Version
@@ -36,6 +37,7 @@ EXPECTED_WARNS = [
     "`np.object` is a deprecated alias",
     "`np.int` is a deprecated alias",
     "sentencepiece tokenizer that you are converting",
+    "Torchmetrics v0.9",  # temporarily allow until _ResultMetric updated
 ]
 MIN_VERSION_WARNS = "1.8"
 MAX_VERSION_WARNS = "1.11"
@@ -65,7 +67,7 @@ def test_examples_fts_superglue(monkeypatch, recwarn, tmpdir, config_file):
         f"--trainer.default_root_dir={tmpdir.strpath}",
         "--trainer.max_epochs=1",
         "--trainer.limit_train_batches=2",
-        "--trainer.gpus=1",
+        "--trainer.devices=1",
     ]
     monkeypatch.setattr("sys.argv", [example_script, "fit", "--config"] + config_loc + cli_args)
     cli_main()
@@ -90,10 +92,34 @@ def test_advanced_examples_fts_superglue(monkeypatch, recwarn, tmpdir, config_fi
         f"--trainer.default_root_dir={tmpdir.strpath}",
         "--trainer.max_epochs=10",
         "--trainer.limit_train_batches=2",
-        "--trainer.gpus=1",
+        "--trainer.devices=1",
     ]
     monkeypatch.setattr("sys.argv", [example_script, "fit", "--config"] + config_loc + cli_args)
     cli_main()
     # ensure no unexpected warnings detected
     matched = [any([re.compile(w).search(w_msg.message.args[0]) for w in ADV_EXPECTED_WARNS]) for w_msg in recwarn.list]
     assert all(matched)
+
+
+@pytest.mark.skipif(not _HF_AVAILABLE, reason="Hugging Face transformers and datasets packages required")
+@RunIf(min_gpus=1, skip_windows=True)
+@pytest.mark.parametrize("nb_name", ["fts_superglue_nb"], ids=["fts_superglue_nb"])
+def test_fts_superglue_nb(recwarn, nb_name):
+    # simple sanity check that the notebook-based version of the example builds and executes successfully
+    test_example_base = os.path.join(os.path.dirname(__file__), "ipynb_src")
+    example_script = os.path.join(test_example_base, f"{nb_name}.py")
+    command = ["python", "-m", "jupytext", "--set-formats", "ipynb,py:percent", example_script]
+    exitcode = subprocess.call(command)
+    assert exitcode == 0
+    example_ipynb = os.path.join(test_example_base, f"{nb_name}.ipynb")
+    assert os.path.exists(example_ipynb)
+    command = ["python", "-m", "pytest", "--nbval", "-v", example_ipynb]
+    exitcode = subprocess.call(command)
+    assert exitcode == 0
+    generated_schedule = os.path.join(test_example_base, "RteBoolqModule_ft_schedule_deberta_base.yaml")
+    for f in [example_ipynb, generated_schedule]:
+        os.remove(f)
+        assert not os.path.exists(f)
+    # ensure no unexpected warnings detected
+    matched = [any([re.compile(w).search(w_msg.message.args[0]) for w in ADV_EXPECTED_WARNS]) for w_msg in recwarn.list]
+    assert all(matched)
